@@ -33,7 +33,7 @@ int pretty = A2T_PRETTY | A2T_NAME;
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -n ]\n",name);
+    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -l logfile ] [ -n ]\n",name);
     exit(1);
 }
 
@@ -47,7 +47,7 @@ int main(int argc,char **argv)
     set_verbosity(NULL,DIAG_INFO);
     dump_dir = DUMP_DIR;
     background = 0;
-    while ((c = getopt(argc,argv,"bdD:np")) != EOF)
+    while ((c = getopt(argc,argv,"bdD:l:np")) != EOF)
 	switch (c) {
 	    case 'b':
 		background = 1;
@@ -59,6 +59,9 @@ int main(int argc,char **argv)
 	    case 'D':
 		dump_dir = optarg;
 		break;
+	    case 'l':
+		set_logfile(optarg);
+		break;
 	    case 'n': /* @@@ was planned for NSAP matching */
 		pretty = A2T_PRETTY;
 		break;
