@@ -19,6 +19,6 @@ int set_ip(int fd,int ip);
 int set_encap(int fd,int mode);
 void send_packet(int fd,void *data,int length);
 int ip_itf_info(int number,unsigned long *ip,unsigned long *netmask);
-int atm_itf_info(struct sockaddr_atmsvc *addr);
+int get_local(int fd,struct sockaddr_atmsvc *addr);
 
 #endif
