@@ -7,6 +7,7 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
+#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
@@ -23,9 +24,37 @@
 #include "atm.h"
 
 
+#define DUMP_DIR "/var/run"
+#define BUF_SIZE 4096
+
+
+static int print_table(void)
+{
+    char buffer[BUF_SIZE];
+    int fd,size;
+
+    if ((fd = open(DUMP_DIR "/atmarpd.table",O_RDONLY)) < 0) {
+	perror("open " DUMP_DIR "/atmarpd.table");
+	return 1;
+    }
+    while ((size = read(fd,buffer,BUF_SIZE))) {
+	if (size < 0) {
+	    perror("read " DUMP_DIR "/atmarpd.table");
+	    return 1;
+	}
+	if (write(0,buffer,size) < 0) {
+	    perror("write stdout");
+	    return 1;
+	}
+    }
+    return 0;
+}
+
+
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s -c [atmN]\n",name);
+    fprintf(stderr,"usage: %s -a\n",name);
+    fprintf(stderr,"%6s %s -c [atmN]\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [temp] [null]\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr atm_addr [temp] [arpsrv]\n","",name);
     fprintf(stderr,"%6s %s -d ip_addr\n","",name);
@@ -41,8 +70,11 @@ int main(int argc,char **argv)
     char *here,*end;
 
     op = 0;
-    while ((c = getopt(argc,argv,"cds")) != EOF)
+    while ((c = getopt(argc,argv,"acds")) != EOF)
 	switch (c) {
+	    case 'a':
+		if (argc != optind) usage(argv[0]);
+		return print_table();
 	    case 'c':
 		if (op) usage(argv[0]);
 		op = SIOCMKCLIP;
