@@ -17,7 +17,8 @@
 static void usage(const char *name)
 {
     fprintf(stderr,"%s: [-z] itf [pool]\n",name);
-    fprintf(stderr,"%s: [-l low_water] [-h high_water] itf [pool]\n",name);
+    fprintf(stderr,"%s: [-l low_water] [-h high_water] [-t threshold] itf "
+      "[pool]\n",name);
     exit(1);
 }
 
@@ -25,13 +26,13 @@ static void usage(const char *name)
 int main(int argc,char **argv)
 {
     char *name,*end;
-    int low_water,high_water,zero;
+    int low_water,high_water,next_thres,zero;
     int itf,pool,first,i;
     int c,s;
 
-    low_water = high_water = zero = 0;
+    low_water = high_water = next_thres = zero = 0;
     name = argv[0];
-    while ((c = getopt(argc,argv,"l:h:z")) != EOF)
+    while ((c = getopt(argc,argv,"l:h:t:z")) != EOF)
 	switch (c) {
 	    case 'l':
 		low_water = strtol(optarg,&end,0);
@@ -41,6 +42,10 @@ int main(int argc,char **argv)
 		high_water = strtol(optarg,&end,0);
 		if (*end || high_water < 0) usage(name);
 		break;
+	    case 't':
+		next_thres = strtol(optarg,&end,0);
+		if (*end || next_thres < 0) usage(name);
+		break;
 	    case 'z':
 		zero = 1;
 	    default:
@@ -73,20 +78,30 @@ int main(int argc,char **argv)
 	if (low_water || high_water) {
 	    req.info.low_water = low_water;
 	    req.info.high_water = high_water;
+	    req.info.next_thres = next_thres;
 	    if (ioctl(s,ZATM_SETPOOL,&sioc) < 0) {
 		perror("ioctl ZATM_SETPOOL");
 		return 1;
 	    }
 	}
 	else {
+	    int size;
+
 	    if (ioctl(s,zero ? ZATM_GETPOOLZ : ZATM_GETPOOL,&sioc) < 0) {
 		perror(zero ? "ioctl ZATM_GETPOOLZ" : "ioctl ZATM_GETPOOL");
 		return 1;
 	    }
-	    if (first) printf("Pool Ref Low High Alarm Under\n");
-	    printf(" %2d  %3d %3d %4d %5d %5d\n",i,req.info.ref_count,
-	      req.info.low_water,req.info.high_water,req.info.rqa_count,
-	      req.info.rqu_count);
+	    if (first)
+		printf("Pool Size Ref Low High Alarm Under Offs NxOf Count "
+		  "Thres\n");
+	    printf(" %2d  ",i);
+	    size = 64 << (i < 2 ? 0 : i-2);
+	    if (size < 1024) printf("%4d",size);
+	    else printf("%3dk",size);
+	    printf(" %3d %3d %4d %5d %5d %4d %4d%6d%6d\n",
+	      req.info.ref_count,req.info.low_water,req.info.high_water,
+	      req.info.rqa_count,req.info.rqu_count,req.info.offset,
+	      req.info.next_off,req.info.next_cnt,req.info.next_thres);
 	}
 	first = 0;
     }
