@@ -22,6 +22,9 @@ typedef enum { /* formatting aligned with state_map and others */
 typedef enum { qs_null,qs_call_init,qs_out_proc = 3,qs_conn_req = 8,
   qs_in_proc,qs_active,qs_rel_req,qs_rel_ind } Q2931_STATE;
 
+typedef enum { ps_null,ps_add_init,ps_add_recv = 6,ps_drop_init = 11,
+  ps_drop_recv,ps_active = 10 } PARTY_STATE;
+
 typedef struct _socket {
     STATE state;
     struct sockaddr_atmpvc pvc;
@@ -33,6 +36,7 @@ typedef struct _socket {
     /* --- Q.93B/Q.2931 information ---------------------------------------- */
     Q2931_STATE q2931_state;
     unsigned long call_ref; /* bit 24 like when sending */
+    short ep_ref; /* endpoint reference; -1 for p2p */
     TIMER *conn_timer; /* current connection timer */
     /* --- some meta-information ------------------------------------------- */
     struct _socket *listen; /* to pending connections, also used for "more" */
@@ -48,6 +52,7 @@ typedef struct _socket {
 
 
 extern const Q2931_STATE state_map[];
+extern const PARTY_STATE eps_map[];
 extern const char *state_name[],*qs_name[],*as_name[];
 
 extern SOCKET *sockets;
