@@ -61,8 +61,9 @@ struct sockaddr_atmsvc *sap_copy(const struct sockaddr_atmsvc *sap)
 static int class_compat(const struct atm_trafprm *tx,
   const struct atm_trafprm *rx)
 {
-    if (tx->class == ATM_NONE) return 1;
-    if (rx->class == ATM_UBR) return 1; /* don't apply CAC to PCR */
+    if (tx->class == ATM_NONE || tx->class == ATM_ANYCLASS) return 1;
+    if (rx->class == ATM_UBR || rx->class == ATM_ANYCLASS) return 1;
+	/* don't apply CAC to PCR */
     if (tx->class != rx->class) return 0;
 	/* ignore special cases like CBR to VBR for now */
     switch (tx->class) {
