@@ -13,7 +13,7 @@ int sap_check_packing(const struct sockaddr_atmsvc *packed_sap,int len);
 struct sockaddr_atmsvc *sap_copy(const struct sockaddr_atmsvc *sap);
 int sap_compat(const struct sockaddr_atmsvc *old,
   const struct sockaddr_atmsvc *new,struct sockaddr_atmsvc **out);
-void sap_encode(Q_DSC *dsc,const struct sockaddr_atmsvc *sap);
+int sap_encode(Q_DSC *dsc,const struct sockaddr_atmsvc *sap);
 struct sockaddr_atmsvc *sap_decode(Q_DSC *dsc);
 
 #endif
