@@ -860,7 +860,7 @@ static void try_to_send(SSCOP_DSC *dsc)
 	    emit_pdu(dsc,buf);
 	    buf2->extra = dsc->vt_ps;
 #ifdef POLL_AFTER_RETRANSMISSION
-	    if (dsc->queue_rt)
+	    if (!queue_peek(dsc->rt_q))
 		/* fall through to goto */
 #endif
 	    goto B; /* sigh ... */
