@@ -31,7 +31,7 @@ void on_T303(void *user) /* CONNECTING */
     sock = user;
     diag(COMPONENT,DIAG_DEBUG,"T303 on 0x%lx",sock->id);
     if (sock->state != ss_connecting) complain(sock,"T303");
-    send_kernel(sock->id,0,as_close,-ETIMEDOUT,NULL);
+    SEND_ERROR(sock->id,-ETIMEDOUT);
     sock->conn_timer = NULL;
     free_sock(sock);
 }
