@@ -1,6 +1,6 @@
 /* timeout.h - Processing of Q.2931 timeout events */
  
-/* Written 1995 by Werner Almesberger, EPFL-LRC */
+/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
  
 
 #ifndef TIMEOUT_H
@@ -9,6 +9,7 @@
 #define T303_TIME	 4000000 /*  4 sec */
 #define T308_1_TIME	30000000 /* 30 sec */
 #define T308_2_TIME	30000000 /* 30 sec */
+#define T309_TIME	10000000 /* 10 sec */
 #define T310_TIME	10000000 /* 10 sec */
 #define T313_TIME	 4000000 /*  4 sec */
 
@@ -21,6 +22,7 @@
 void on_T303(void *user);
 void on_T308_1(void *user);
 void on_T308_2(void *user);
+void on_T309(void *user);
 void on_T310(void *user);
 void on_T313(void *user);
 
