@@ -50,8 +50,8 @@ int main(int argc,char **argv)
 
 	start = (unsigned char *) (((unsigned long) buf+4095) & ~4095U);
 	size = read(s,start,BSIZE);
-	printf("%d:",size);
-	if (size < 0) printf("(%s)",strerror(errno));
+	printf("%d",size);
+	if (size < 0) printf(" (%s)",strerror(errno));
 	printf(": ");
 	for (i = 0; i < size; i++) printf(" %02X",start[i]);
 	putchar('\n');
