@@ -38,7 +38,7 @@ int main(int argc,char **argv)
     addr.sap_txtp.max_sdu = strlen(argv[2])-offset;
     offset = argc == 3 ? 0 : atoi(argv[3]);
     if (connect(s,(struct sockaddr *) &addr,sizeof(addr)) < 0) {
-	perror("bind");
+	perror("connect");
 	return 1;
     }
     size = write(s,argv[2]+offset,strlen(argv[2])-offset);
