@@ -60,6 +60,7 @@ static char RCSid[] = "ttcp.c $Revision: 1.12 $";
 #include <sys/time.h>		/* struct timeval */
 #include <linux/atm.h>
 #include <atm.h>
+#include <arequipa.h>
 
 #if defined(SYSV)
 #include <sys/times.h>
@@ -90,6 +91,9 @@ int bufalign = 16*1024;		/* modulo this */
 
 int atm = 0;			/* 0 = INET, !0 = ATM */
 int pcr = 0;
+int arequipa = 0;
+char *aq_host;
+
 int udp = 0;			/* 0 = tcp, !0 = udp */
 int options = 0;		/* socket options */
 int one = 1;                    /* for 4.3 BSD style setsockopt() */
@@ -180,9 +184,13 @@ int no_check = 0;
 
     if (argc < 2) goto usage;
 
-    while ((c = getopt(argc, argv, "adrstuvBDTb:f:l:n:p:P:A:O:C")) != -1) {
+    while ((c = getopt(argc, argv, "Q:adrstuvBDTb:f:l:n:p:P:A:O:C")) != -1) {
 	switch (c) {
 
+	  case 'Q':
+	    arequipa = 1;
+	    aq_host = optarg;
+	    break;
 	  case 'a':
 	    atm = udp = 1;
 	    break;
@@ -257,11 +265,16 @@ int no_check = 0;
     }
     
     host = argv[optind];
-    if (atm) {
+    if (atm && arequipa) {
+	fprintf(stderr,"-Q must not be used with -a\n");
+	return 1;
+    }
+
+    if (atm || (arequipa && trans)) {
 	memset(satm,0,sizeof(satm));
 	if (!host) satm.sas_family = AF_ATMSVC;
-	else if (text2atm(host,(struct sockaddr *) &satm,sizeof(satm),
-	      T2A_PVC | T2A_SVC | T2A_NAME) < 0) {
+	else if (text2atm(atm ? host : aq_host,(struct sockaddr *) &satm,
+	      sizeof(satm),T2A_PVC | T2A_SVC | T2A_NAME) < 0) {
 		fprintf(stderr,"invalid ATM address (PVC or SVC expected)\n");
 		exit(1);
 	    }
@@ -273,9 +286,9 @@ int no_check = 0;
 		qos.txtp.max_pcr = pcr;
 	    }
 	qos.rxtp.max_sdu = qos.txtp.max_sdu = buflen;
+	if (arequipa && !udp) qos.rxtp = qos.txtp;
     }
-    else
-    if (trans)  {
+    if (!atm && trans)  {
 	/* xmitr */
 	if (optind == argc)
 	    goto usage;
@@ -342,6 +355,10 @@ int no_check = 0;
         udp?SOCK_DGRAM:SOCK_STREAM, atm ? ATM_AAL5 : 0)) < 0) err("socket");
     
     mes("socket");
+	if (arequipa && trans) {
+	    if (arequipa_preset(fd,&satm,&qos) < 0)
+		err("arequipa_preset");
+	}
 	if (atm) {
 	    if (setsockopt(fd,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
 		err("setsockopt SO_ATMQOS");
@@ -373,8 +390,11 @@ int no_check = 0;
 	  sizeof(struct sockaddr_atmpvc) : sizeof(struct sockaddr_atmsvc) :
 	  sizeof(sinme)) < 0)
 	    err("bind");
-    
-    if (!udp || (atm && satm.sas_family == AF_ATMSVC)) {
+
+    if (arequipa && !trans && !udp)
+	if (arequipa_expect(fd,1) < 0) err("arequipa_expect");
+
+    if (!udp || arequipa || (atm && satm.sas_family == AF_ATMSVC)) {
 	signal(SIGPIPE, sigpipe);
 	if (trans) {
 	    /* We are the client if transmitting */
@@ -402,7 +422,7 @@ int no_check = 0;
 		mes("nodelay");
 	    }
 #endif
-	} else {
+	} else if (!arequipa || !udp) {
 	    /* otherwise, we are the server and 
 	     * should listen for the connections
 	     */
@@ -921,7 +941,7 @@ int count;
     
     if (udp)  {
       again:
-	if (atm) cnt = write(fd, buf, count);
+	if (atm || arequipa) cnt = write(fd, buf, count);
 	else cnt = sendto(fd, buf, count, 0, &sinhim, sizeof(sinhim));
 	numCalls++;
 	if ( cnt<0 && errno == ENOBUFS )  {
